"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Container = void 0;
const inversify_1 = require("inversify");
const constants_1 = require("./constants");
const errors_1 = require("./errors");
class Container extends inversify_1.Container {
    get(serviceIdentifier) {
        try {
            return super.get(serviceIdentifier);
        }
        catch (e) {
            const message = e.message;
            if (message.includes('No matching bindings found')) {
                if (message.includes(constants_1.CONFIG_TOKEN_IDENTIFIER)) {
                    const packageName = message // Symbol(CONFIG_TOKEN_IDENTIFIER "PackageName")
                        .split(constants_1.CONFIG_TOKEN_IDENTIFIER)[1]
                        .slice(0, -1)
                        .trim();
                    throw new errors_1.ConfigNotFoundError({
                        packageName,
                    });
                }
                if (message.includes(constants_1.SERVICE_TOKEN_IDENTIFIER)) {
                    const serviceName = message // Symbol(SERVICE_TOKEN_IDENTIFIER "ServiceName")
                        .split(constants_1.SERVICE_TOKEN_IDENTIFIER)[1]
                        .slice(0, -1)
                        .trim();
                    throw new errors_1.ServiceNotFoundError({
                        serviceName,
                    });
                }
            }
            throw e;
        }
    }
}
exports.Container = Container;
