"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Core = void 0;
/* eslint-disable @typescript-eslint/ban-ts-comment */
const container_1 = require("./container");
const defs_1 = require("./defs");
const errors_1 = require("./errors");
class Core {
    constructor(config) {
        this.config = config;
        this._state = defs_1.CoreState.NEW;
    }
    get state() {
        return this._state;
    }
    get isNew() {
        return this.state === defs_1.CoreState.NEW;
    }
    get isInitialised() {
        return this.state === defs_1.CoreState.INITIALIZED;
    }
    get isInitialising() {
        return this.state === defs_1.CoreState.INITIALIZING;
    }
    get container() {
        if (this._container == null) {
            this._container = new container_1.Container({
                skipBaseClassChecks: true,
            });
        }
        return this._container;
    }
    checkPackagesDependencies() {
        for (const pkg of this.config.packages) {
            const dependencies = pkg.getDependencies();
            for (const PackageDependency of dependencies) {
                if (!this.config.packages.some((pkg) => pkg instanceof PackageDependency)) {
                    throw new errors_1.DependencyNotFoundError({
                        dependency: PackageDependency.name,
                        dependent: pkg.constructor.name,
                    });
                }
            }
        }
    }
    async initialise() {
        if (!this.isNew) {
            return;
        }
        this.checkPackagesDependencies();
        for (const pkg of this.config.packages) {
            // @ts-ignore
            pkg.__setCore(this);
        }
        this._state = defs_1.CoreState.INITIALIZING;
        for (const pkg of this.config.packages) {
            await pkg.bind();
        }
        for (const pkg of this.config.packages) {
            await pkg.initialise();
        }
        this._state = defs_1.CoreState.INITIALIZED;
    }
    async shutdown() {
        // TODO
    }
}
exports.Core = Core;
